@@ -61,7 +61,7 @@ class ClBuilderMenuAction(Action):
              Get('os_root_type_ext') in RootType.IsoScanGrub)
          },
         {'name': 'grub:update_grub_menu',
-         'message': __("Creating the ISO images menu"),
+         'message': __("Creating the Live HDD menu"),
          'method': 'Builder.create_iso_grub_cfg(cl_builder_livemenu_path)',
          'condition': lambda Get: (
              Get('builder.cl_builder_livemenu_path') != "")
@@ -97,7 +97,7 @@ class ClBuilderMenuAction(Action):
          'method': 'Builder.sync_vmlinuz(cl_builder_flash_path)'
          },
         {'name': 'image_menu:update_menu',
-         'message': __("Recreating the ISO images menu"),
+         'message': __("Recreating the Live USB menu"),
          'method': 'Builder.update_menu(cl_builder_flash_path)',
          },
     ]
