@@ -1445,7 +1445,7 @@ class VariableClBuilderLivemenuPath(Variable):
         elif root_type_ext in RootType.Grubable:
             live_path = self.get_live_path()
             if live_path:
-                yield (live_path, _("ISO images directory (%s)") % live_path)
+                yield (live_path, _("Distributions directory (%s)") % live_path)
         for dev in self.select('install.os_disk_dev',
                                install_os_disk_format="vfat"):
             yield (dev, self.flash_name(dev))
